@@ -17,6 +17,7 @@ import math
 import matplotlib.pyplot as plt
 import itertools
 from IPython.display import display
+from pytorch_hyperlight.utils.metric_dict_utils import MetricDictUtils
 
 TRAIN_SUFFIX = "train"
 VAL_SUFFIX = "val"
@@ -84,6 +85,26 @@ class TrialMetrics:
             )
         ]
         metrics_df["stage-list"] = metrics_df["stage-list"].apply(tuple)
+
+        col_stage_list = MetricDictUtils.get_list_prefix_list(
+            metrics_df.columns, split_symbol_list=["_", "-"]
+        )
+        for i_col, col in enumerate(metrics_df.columns):
+            if col in self.ALL_INDEX_COLUMN_LIST:
+                continue
+            col_stage = col_stage_list[i_col]
+            stage_list = (
+                metrics_df.loc[~metrics_df[col].isna(), "stage-list"]
+                .apply(set)
+                .tolist()
+            )
+
+            bad_stage_list = [x for x in stage_list if col_stage not in x]
+
+            assert (
+                len(bad_stage_list) == 0
+            ), f'column "{col}" related to stage "{col_stage}" contains not NaN values for stages {bad_stage_list}'
+
         self.__metrics_df = metrics_df
 
     @staticmethod
@@ -109,7 +130,7 @@ class TrialMetrics:
     series_last = property(get_series_last)
 
     @staticmethod
-    def create_axes(n_graphs, figsize=None, max_cols=2):
+    def create_subplots(n_graphs, figsize=None, max_cols=2):
         SUBPLOT_WIDTH = 20
         SUBPLOT_HEIGHT = 12
         MAX_COLS = max_cols
@@ -121,7 +142,7 @@ class TrialMetrics:
         ax_list = [None] * n_graphs
         for i_graph in range(n_graphs):
             ax_list[i_graph] = fig.add_subplot(n_rows, n_cols, i_graph + 1)
-        return ax_list
+        return fig, ax_list
 
     def plot(self, **kwargs):
         cols2drop_list = list(
@@ -142,7 +163,7 @@ class TrialMetrics:
         metric_name_list = list(set(df.columns.get_level_values(0)))
         n_metrics = len(metric_name_list)
 
-        ax_list = self.create_axes(n_metrics, **kwargs)
+        fig, ax_list = self.create_subplots(n_metrics, **kwargs)
 
         for i_metric, ax in enumerate(ax_list):
             metric_name = metric_name_list[i_metric]
@@ -151,6 +172,11 @@ class TrialMetrics:
             metric_df.index = metric_df.index.droplevel(0)
             style_list = get_df_column_styles(metric_df)
             self.plot_df_with_dropped_nans(metric_df, ax, style_list, ms=5, grid=True)
+        return fig, ax_list
+
+    @staticmethod
+    def from_metrics_df_list(metrics_df_list):
+        return TrialMetrics(MetricDictUtils.metrics_df_list_concat(metrics_df_list))
 
     @staticmethod
     def plot_df_with_dropped_nans(df, ax, style_list, **kwargs):
